@@ -10,6 +10,35 @@ from slack_sdk import WebClient
 from slack_sdk.errors import SlackApiError
 
 
+class SSHFinanceTunnel:
+    def __init__(self, credential_path: str):
+        self.credentials = yaml.safe_load(open(credential_path, "r"))
+        self.host = self.credentials['SSH_ABACUS']['SSH_HOST']
+        self.port = self.credentials['SSH_ABACUS']['SSH_PORT']
+        self.path = self.credentials['SSH_ABACUS']['SSH_PATH']
+        self.username = self.credentials['SSH_ABACUS']['SSH_USER']
+        self.key_phrase = self.credentials['SSH_ABACUS']['SSH_KEYPHRASE']
+        self.client = None
+        self.__connect()
+        self.__start()
+
+    def __connect(self):
+        self.client = sshtunnel.SSHTunnelForwarder(
+            (self.host, self.port),
+            ssh_username=self.username,
+            ssh_pkey=self.path,
+            ssh_private_key_password=self.key_phrase,
+            remote_bind_address=('127.0.0.1', 3306))
+        return self.client
+
+    def __start(self):
+        self.client.start()
+
+    def disconnect(self):
+        self.client.stop()
+        print("Client disconnected")
+
+
 class SSHTunnel:
     def __init__(self, credential_path: str, datamart: bool = True):
         self.credentials = yaml.safe_load(open(credential_path, "r"))
@@ -44,7 +73,7 @@ class SSHTunnel:
                 ssh_username=self.username,
                 ssh_pkey=self.path,
                 ssh_private_key_password=self.key_phrase,
-                remote_bind_address=('localhost', 9000))
+                remote_bind_address=('127.0.0.1', 9000))
         return self.client
 
     def __start(self):
@@ -58,9 +87,9 @@ class SSHTunnel:
 class ClickConnection:
     def __init__(self, db_name: str, credential_path: str, ssh_tunnel: SSHTunnel):
         self.credentials = yaml.safe_load(open(credential_path, "r"))
-        self.host = self.credentials['CLICK_CREDENTIALS_FLOW']['HOST']
-        self.user = self.credentials['CLICK_CREDENTIALS_FLOW']['USER']
-        self.password = self.credentials['CLICK_CREDENTIALS_FLOW']['PASSWORD']
+        self.host = self.credentials['CLICK_CREDENTIALS']['HOST']
+        self.user = self.credentials['CLICK_CREDENTIALS']['USER']
+        self.password = self.credentials['CLICK_CREDENTIALS']['PASSWORD']
         self.ssh_tunnel = ssh_tunnel
         self.port = ssh_tunnel.client.local_bind_port
         self.dbname = db_name
@@ -81,7 +110,7 @@ class ClickConnection:
                                                                                                   port=self.port,
                                                                                                   dbname=self.dbname)
         self.connector = clickhouse_driver.connect(connection_string)
-        self.client = clickhouse_driver.Client(host='localhost', port=self.port, database=self.dbname,
+        self.client = clickhouse_driver.Client(host='127.0.0.1', port=self.port, database=self.dbname,
                                                password=self.password,
                                                settings={"use_numpy": True})
         self.coursor = self.connector.cursor()
@@ -196,6 +225,71 @@ class MySqlConnection:
         self.coursor.execute(sql, params or ())
 
 
+class MySqlFinanceConnection:
+    def __init__(self, db_name: str, credential_path: str, ssh_tunnel: SSHTunnel):
+        self.credentials = yaml.safe_load(open(credential_path, "r"))
+        self.host = self.credentials['ABACUS_CREDENTIALS']['HOST']
+        self.user = self.credentials['ABACUS_CREDENTIALS']['USER']
+        self.password = self.credentials['ABACUS_CREDENTIALS']['PASSWORD']
+        self.ssh_tunnel = ssh_tunnel
+        self.port = ssh_tunnel.client.local_bind_port
+        self.dbname = db_name
+        self.connector = None
+        self.coursor = None
+        self.__connection()
+        self.engine = sqlalchemy.create_engine(
+            'mysql+pymysql://' + self.user + ':' + self.password + '@' + self.host + ':' + str(self.port) + '/' \
+            + self.dbname + '?charset=utf8mb4')
+
+    def __connection(self):
+        self.connector = pymysql.connect(
+            host='127.0.0.1',
+            user=self.user,
+            passwd=self.password,
+            db=self.dbname,
+            port=self.port)
+        self.coursor = self.connector.cursor()
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.close()
+
+    @property
+    def connection(self):
+        return self.connector
+
+    @property
+    def cursor(self):
+        return self.coursor
+
+    def commit(self):
+        self.connection.commit()
+
+    def close(self, commit=True):
+        if commit:
+            self.commit()
+        self.connection.close()
+        print("Connection disconnected")
+
+    def close_with_ssh(self, commit=True):
+        if commit:
+            self.commit()
+        self.ssh_tunnel.disconnect()
+        self.connection.close()
+
+    def query(self, sql: str, params=None):
+        self.coursor.execute(sql, params or ())
+        return self.cursor.fetchall()
+
+    def query_pandas(self, sql: str):
+        return pd.read_sql_query(sql, self.connector)
+
+    def execute(self, sql: str, params=None):
+        self.coursor.execute(sql, params or ())
+
+
 class TgConnection:
     def __init__(self, credential_path: str, chat_id: str):
         self.credentials = yaml.safe_load(open(credential_path, "r"))
